==> zio-aws-iotanalytics_2.12-5.17.193.2-sources.jar: zio/aws/iotanalytics/model/ChannelStatistics.scala <==
package zio.aws.iotanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ChannelStatistics(
    size: Optional[zio.aws.iotanalytics.model.EstimatedResourceSize] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics = {
    import ChannelStatistics.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics
      .builder()
      .optionallyWith(size.map(value => value.buildAwsValue()))(_.size)
      .build()
  }
  def asReadOnly: zio.aws.iotanalytics.model.ChannelStatistics.ReadOnly =
    zio.aws.iotanalytics.model.ChannelStatistics.wrap(buildAwsValue())
}
object ChannelStatistics {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotanalytics.model.ChannelStatistics =
      zio.aws.iotanalytics.model
        .ChannelStatistics(size.map(value => value.asEditable))
    def size
        : Optional[zio.aws.iotanalytics.model.EstimatedResourceSize.ReadOnly]
    def getSize: ZIO[
      Any,
      AwsError,
      zio.aws.iotanalytics.model.EstimatedResourceSize.ReadOnly
    ] = AwsError.unwrapOptionField("size", size)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics
  ) extends zio.aws.iotanalytics.model.ChannelStatistics.ReadOnly {
    override val size
        : Optional[zio.aws.iotanalytics.model.EstimatedResourceSize.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.size())
        .map(value =>
          zio.aws.iotanalytics.model.EstimatedResourceSize.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics
  ): zio.aws.iotanalytics.model.ChannelStatistics.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iotanalytics_2.13-5.17.104.7-sources.jar: zio/aws/iotanalytics/model/ChannelStatistics.scala <==
package zio.aws.iotanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ChannelStatistics(
    size: Option[zio.aws.iotanalytics.model.EstimatedResourceSize] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics = {
    import ChannelStatistics.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics
      .builder()
      .optionallyWith(size.map(value => value.buildAwsValue()))(_.size)
      .build()
  }
  def asReadOnly: zio.aws.iotanalytics.model.ChannelStatistics.ReadOnly =
    zio.aws.iotanalytics.model.ChannelStatistics.wrap(buildAwsValue())
}
object ChannelStatistics {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotanalytics.model.ChannelStatistics =
      zio.aws.iotanalytics.model
        .ChannelStatistics(size.map(value => value.asEditable))
    def size: Option[zio.aws.iotanalytics.model.EstimatedResourceSize.ReadOnly]
    def getSize: ZIO[
      Any,
      AwsError,
      zio.aws.iotanalytics.model.EstimatedResourceSize.ReadOnly
    ] = AwsError.unwrapOptionField("size", size)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics
  ) extends zio.aws.iotanalytics.model.ChannelStatistics.ReadOnly {
    override val size
        : Option[zio.aws.iotanalytics.model.EstimatedResourceSize.ReadOnly] =
      scala
        .Option(impl.size())
        .map(value =>
          zio.aws.iotanalytics.model.EstimatedResourceSize.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotanalytics.model.ChannelStatistics
  ): zio.aws.iotanalytics.model.ChannelStatistics.ReadOnly = new Wrapper(impl)
}
